"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const gatsby_source_filesystem_1 = require("gatsby-source-filesystem");
// reference:
// https://www.gatsbyjs.org/packages/gatsby-source-filesystem/#createremotefilenode
async function downloadNotionImages(pageNodesDict, getNodes, createNode, createParentChildLink, createNodeId, store, cache, createContentDigest, notionLoader, pluginConfig, reporter) {
    // we retrieve all the notion nodes which have been created
    // and we see if they have images associated to them
    // TODO: add filtering pertype (eg. NotionPageBlog) to allow
    // multiple instanes of the plugin to coexist
    const imagesNodes = getNodes().filter((n) => {
        return n.internal && n.internal.owner === 'gatsby-source-notionso';
    });
    const imagesToDownload = [];
    await Promise.all(imagesNodes.map(async (node) => {
        (node.images || []).forEach(image => {
            imagesToDownload.push([image.notionUrl, image.contentId, image.pageId]);
        });
    }));
    const result = await notionLoader.downloadImages(imagesToDownload);
    reporter.info(`Images for notion source: ${result}`);
    for (const img of result) {
        const [notionUrl, signedUrl, pageId] = img;
        const fileNode = await gatsby_source_filesystem_1.createRemoteFileNode({
            url: signedUrl,
            store,
            cache,
            createNode,
            createNodeId,
            reporter,
        });
        const assetNodeId = createNodeId(notionUrl);
        const item = {
            notionUrl,
            pageId,
            // check:
            // https://www.gatsbyjs.org/docs/node-creation/#foreign-key-reference-___node
            // https://www.gatsbyjs.org/docs/schema-gql-type#foreign-key-reference-___node
            // eslint-disable-next-line @typescript-eslint/camelcase
            localFile___NODE: fileNode.id,
        };
        const assetNode = Object.assign(Object.assign({}, item), { id: assetNodeId, _id: assetNodeId, parent: undefined, children: [], internal: {
                contentDigest: createContentDigest(item),
                type: `NotionPageAsset${pluginConfig.name}`,
            } });
        createNode(assetNode);
        // create the link between the page and its images
        // https://www.gatsbyjs.org/docs/actions/#createParentChildLink
        const pageNode = pageNodesDict[pageId];
        if (pageNode) {
            createParentChildLink({
                parent: pageNode,
                child: assetNode,
            });
        }
        else {
            reporter.error(`Could not find page node for pageId:${pageId}`);
        }
    }
}
exports.default = downloadNotionImages;
//# sourceMappingURL=downloadNotionImages.js.map